@@ -283,7 +283,7 @@ class TestUUID(TestField):
             ('da66a411-af0e-4829-9b67-475017ddz152',
                 'da66a411-af0e-4829-9b67-475017ddz152'),
             ('fake_uuid', 'fake_uuid'),
-            (u'fake_uāid', u'fake_uāid'),
+            ('fake_uāid', 'fake_uāid'),
             (b'fake_u\xe1id'.decode('latin_1'),
                 b'fake_u\xe1id'.decode('latin_1')),
             ('1', '1'),
