@@ -584,7 +584,7 @@ class TestObjectVersionChecker(test.TestCase):
         argspec = 'cubone'
         self._add_class(self.obj_classes, ExtraDataObj)
 
-        with mock.patch('inspect.getargspec') as mock_gas:
+        with mock.patch.object(fixture, 'get_method_spec') as mock_gas:
             mock_gas.return_value = argspec
             fp = self.ovc._get_fingerprint(ExtraDataObj.__name__,
                                            extra_data_func=get_data)
@@ -757,9 +757,15 @@ class TestMethodSpec(test.TestCase):
         self._test_method3 = test_method3
 
     def test_method_spec_compat(self):
-        self.assertEqual(inspect.getargspec(self._test_method1),
+        self.assertEqual(fixture.CompatArgSpec(args=['a', 'b', 'kw1'],
+                                               varargs=None,
+                                               keywords='kwargs',
+                                               defaults=(123,)),
                          fixture.get_method_spec(self._test_method1))
-        self.assertEqual(inspect.getargspec(self._test_method2),
+        self.assertEqual(fixture.CompatArgSpec(args=['a', 'b'],
+                                               varargs='args',
+                                               keywords=None,
+                                               defaults=None),
                          fixture.get_method_spec(self._test_method2))
         self.assertEqual(inspect.getfullargspec(self._test_method3),
                          fixture.get_method_spec(self._test_method3))
